@@ -1,6 +1,6 @@
 # Device::Modem::Log::Syslog - Syslog logging plugin for Device::Modem class
 #
-# Copyright (C) 2002 Cosimo Streppone, cosimo@cpan.org
+# Copyright (C) 2002-2004 Cosimo Streppone, cosimo@cpan.org
 #
 # This program is free software; you can redistribute it and/or
 # modify it under the same terms as Perl itself.
@@ -9,10 +9,10 @@
 # testing and support for generic AT commads, so use it at your own risk,
 # and without ANY warranty! Have fun.
 #
-# $Id: Syslog.pm,v 1.8 2003/05/20 05:19:37 cosimo Exp $
+# $Id: Syslog.pm,v 2.1 2004-11-10 09:12:14 cosimo Exp $
 
 package Device::Modem::Log::Syslog;
-$VERSION = substr q$Revision: 1.8 $, 10;
+$VERSION = sprintf '%d.%02d', q$Revision: 2.1 $ =~ /(\d+)\.(\d+)/;
 
 use strict;
 use Sys::Syslog ();
@@ -44,7 +44,7 @@ sub loglevel {
 		$$self = $newlevel;
 
 		# Set new logmask
-		my $logmask = (1 << ($levels{$newlevel} + 1)) - 1;
+		my $logmask = 0xFF; #(1 << ($levels{$newlevel} + 1)) - 1;
 		Sys::Syslog::setlogmask( $logmask );
 
 	} else {
@@ -56,10 +56,8 @@ sub loglevel {
 
 sub write($$) {
 	my($self, $level, @msg) = @_;
-	if( lc($level) eq 'verbose' ) {
-		$level = 'info';
-	}
 	Sys::Syslog::syslog( $level, @msg );
+	return 1;
 }
 
 }
